@@ -22,7 +22,7 @@ def do_get_env(args):
     trtpy.init(cuda_version=args.cuda, tensorrt_version=args.trt)
     print(f"Environment info: ")
     trtpy.print_pyc(trtpy.current_pyc)
-    print("Done, Useage: 'import trtpy.init_default as trtpy'")
+    print("Done, Usage: 'import trtpy.init_default as trtpy'")
     return 0
 
 def do_info(args):
@@ -135,6 +135,7 @@ def get_variable_template():
     variable_template.append(["TRTPRO_INCLUDE", f"{trtpy.trtpy_root}/include"])
     variable_template.append(["SYS_LIB", f"{trtpy.trtpy_root}/lib"])
     variable_template.append(["PYTHON_LINK_NAME", f"{trtpy.pydll_link_name}"])
+    variable_template.append(["PYTHON_INCLUDE", f"{sys.exec_prefix}/include/{trtpy.pydll_link_name}"])
     variable_template.append(["PYTHON_LIB", f"{trtpy.pydll_path}"])
     
     if trtpy.inited:
